import React from 'react';
import {connect} from 'react-redux';
import {getAllTopics, getRandomTopicVideos} from '../actions/topics';
import {getAllPlaces, getRandomPlaceVideos} from '../actions/places';
import RandomPlace from "../components/RandomPlace";
import RandomDate from "../components/RandomDate";
import RandomTopic from "../components/RandomTopic";

class Home extends React.Component {
  componentDidMount() {
    if (this.props.allTopics && this.props.allTopics.length > 0 && !this.props.randomTopic) {
      this.props.getRandomTopicVideos(this.props.allTopics);
    } else {
      this.props.getAllTopics();
    }
    this.props.getRandomPlaceVideos();
  }

  componentWillReceiveProps(nextProps) {
    // This is slightly awkward - we need to check that we have all topics,
    // But don't have a random topic yet (or at not already loading a random topic)
    if ((this.props.allTopics || nextProps.allTopics) && !this.props.loadingRandomTopic && !nextProps.loadingRandomTopic && !this.props.randomTopic) {
      this.props.getRandomTopicVideos(nextProps.allTopics);
    }
  }

  render() {
    return (
      <div>
        <RandomTopic
          topicName={this.props.randomTopic || ''}
          allTopics={this.props.allTopics || []}
          topicCount={this.props.randomTopicCount}
          videos={this.props.randomTopicVideos || []}
          loading={this.props.loadingAllTopics || this.props.loadingRandomTopic}
          getRandomTopicVideos={this.props.getRandomTopicVideos}
        />
        <RandomPlace
          place={this.props.randomPlace}
          placeName={this.props.randomPlaceName || null}
          placeId={this.props.randomPlaceId || ''}
          placeCount={this.props.randomPlaceCount || null}
          videos={this.props.randomPlaceVideos || []}
          loading={this.props.loadingRandomPlace}
          getRandomPlaceVideos={this.props.getRandomPlaceVideos}
        />
        <RandomDate/>
      </div>
    );
  }
}

const mapStateToProps = state => ({
  allTopics: state.topics.allTopics,
  loadingAllTopics: state.topics.loadingAllTopics,
  randomTopic: state.topics.randomTopic,
  randomTopicCount: state.topics.randomTopicCount,
  loadingRandomTopic: state.topics.loadingRandomTopic,
  randomTopicVideos: state.topics.randomTopicVideos,

  // places
  randomPlace: state.places.randomPlace,
  randomPlaceName: state.places.randomPlaceName,
  randomPlaceId: state.places.randomPlaceId,
  randomPlaceCount: state.places.randomPlaceCount,
  loadingRandomPlace: state.places.loadingRandomPlace,
  randomPlaceVideos: state.places.randomPlaceVideos,
});

const mapDispatchToProps = dispatch => ({
  getAllTopics: () => dispatch(getAllTopics()),
  getRandomTopicVideos: allTopics => dispatch(getRandomTopicVideos(allTopics)),
  // places
  getAllPlaces: () => dispatch(getAllPlaces()),
  getRandomPlaceVideos: () => dispatch(getRandomPlaceVideos()),

});

export default connect(mapStateToProps, mapDispatchToProps)(Home);